# aws-easy-use
![CI](https://github.com/imaging8896/aws-easy-use/actions/workflows/push_any_branch.yml/badge.svg?branch=master)
![Release](https://github.com/imaging8896/aws-easy-use/actions/workflows/push_release_tag.yml/badge.svg)

AWS boto3 wrapper. Make it easier and intuitive to use.
